[yocto-autobuilder2] [PATCH 2/2] schedulers: Add wrynose scheduled jobs

Richard Purdie <[email protected]>
Newsgroups org.yoctoproject.lists.yocto-patches
Message-ID <[email protected]>
Signed-off-by: Richard Purdie <[email protected]>
---
 schedulers.py | 18 +++++++++---------
 1 file changed, 9 insertions(+), 9 deletions(-)

diff --git a/schedulers.py b/schedulers.py
index ee8887d3..67fdd39d 100644
--- a/schedulers.py
+++ b/schedulers.py
@@ -656,16 +656,16 @@ schedulers.append(sched.Nightly(name='nightly-metrics-dunfell', branch='dunfell'
 schedulers.append(sched.Nightly(name='nightly-metrics-kirkstone', branch='kirkstone', properties=parent_default_props('metrics', 'kirkstone'), builderNames=['metrics'], hour=6, minute=15, codebases = {'' : {'branch' : 'kirkstone'}}))
 schedulers.append(sched.Nightly(name='nightly-metrics-scarthgap', branch='scarthgap', properties=parent_default_props('metrics', 'scarthgap'), builderNames=['metrics'], hour=6, minute=30, codebases = {'' : {'branch' : 'scarthgap'}}))
 schedulers.append(sched.Nightly(name='nightly-metrics-whinlatter', branch='whinlatter', properties=parent_default_props('metrics', 'whinlatter'), builderNames=['metrics'], hour=6, minute=45, codebases = {'' : {'branch' : 'whinlatter'}}))
-schedulers.append(sched.Nightly(name='nightly-metrics-walnascar', branch='walnascar', properties=parent_default_props('metrics', 'walnascar'), builderNames=['metrics'], hour=7, minute=0, codebases = {'' : {'branch' : 'walnascar'}}))
+schedulers.append(sched.Nightly(name='nightly-metrics-wrynose', branch='wrynose', properties=parent_default_props('metrics', 'wrynose'), builderNames=['metrics'], hour=7, minute=0, codebases = {'' : {'branch' : 'wrynose'}}))
 schedulers.append(sched.Nightly(name='nightly-metrics', branch='master', properties=parent_default_props('metrics'), builderNames=['metrics'], hour=7, minute=15))
 schedulers.append(sched.Nightly(name='nightly-metrics-gitstats', branch='master', properties=parent_default_props('metrics-gitstats'), builderNames=['metrics-gitstats'], hour=4, minute=0))
 
-# Run check-layer-nightly twice a week for whinlatter
-schedulers.append(sched.Nightly(name='nightly-check-layer-whinlatter', properties=parent_default_props('check-layer-nightly', 'whinlatter'),
-                  builderNames=['check-layer-nightly'], dayOfWeek=[1, 4], hour=2, minute=0, codebases = {'' : {'branch' : 'whinlatter'}}))
-# Run meta-oe-mirror twice a month for whinlatter
-schedulers.append(sched.Nightly(name='nightly-meta-oe-mirror-whinlatter', properties=parent_default_props('meta-oe-mirror', 'whinlatter'),
-                  builderNames=['meta-oe-mirror'], dayOfMonth=[3, 17], hour=2, minute=0, codebases = {'' : {'branch' : 'whinlatter'}}))
+# Run check-layer-nightly twice a week for wrynose
+schedulers.append(sched.Nightly(name='nightly-check-layer-wrynose', properties=parent_default_props('check-layer-nightly', 'wrynose'),
+                  builderNames=['check-layer-nightly'], dayOfWeek=[1, 4], hour=2, minute=0, codebases = {'' : {'branch' : 'wrynose'}}))
+# Run meta-oe-mirror twice a month for wrynose
+schedulers.append(sched.Nightly(name='nightly-meta-oe-mirror-wrynose', properties=parent_default_props('meta-oe-mirror', 'wrynose'),
+                  builderNames=['meta-oe-mirror'], dayOfMonth=[3, 17], hour=2, minute=0, codebases = {'' : {'branch' : 'wrynose'}}))
 
 # Run check-layer-nightly twice a week for scarthgap
 schedulers.append(sched.Nightly(name='nightly-check-layer-scarthgap', properties=parent_default_props('check-layer-nightly', 'scarthgap'),
@@ -699,7 +699,7 @@ schedulers.append(sched.Nightly(name='sschduler-indexing', branch='master', prop
 
 # If any of our sphinx docs branches change, trigger a build
 schedulers.append(sched.AnyBranchScheduler(name="yocto-docs-changed",
-            change_filter=util.ChangeFilter(project=["yocto-docs"], branch=[None, "master", "master-next", "whinlatter", "walnascar", "styhead", "scarthgap", "mickledore", "langdale", "kirkstone", "honister", "hardknott", "gatesgarth", "dunfell", "transition"]),
+            change_filter=util.ChangeFilter(project=["yocto-docs"], branch=[None, "master", "master-next", "wrynose", "whinlatter", "walnascar", "styhead", "scarthgap", "mickledore", "langdale", "kirkstone", "honister", "hardknott", "gatesgarth", "dunfell", "transition"]),
             codebases = ['yab-helper', 'yocto-docs', 'bitbake'],
             treeStableTimer=60,
             properties=repos_dict_for_scheduler("docs"),
@@ -712,7 +712,7 @@ def isbitbakeDocFile(change):
             return True
     return False
 schedulers.append(sched.AnyBranchScheduler(name="bitbake-docs-changed",
-            change_filter=util.ChangeFilter(project=["bitbake"], branch=["master", "2.16", "2.10", "2.8", "2.0"]),
+            change_filter=util.ChangeFilter(project=["bitbake"], branch=["master", "2.18", "2.16", "2.10", "2.8", "2.0"]),
             codebases = ['yab-helper', 'yocto-docs', 'bitbake'],
             fileIsImportant=isbitbakeDocFile,
             onlyImportant=True,
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.